add "LE Device Address" 0x1B to advertising data types

Fork of BLE_API by Bluetooth Low Energy

Revision:
1076:5f938eb2bd6a
Parent:
1075:0d0dafb54bc9
--- a/ble/BLEProtocol.h	Mon Jan 11 08:51:43 2016 +0000
+++ b/ble/BLEProtocol.h	Mon Jan 11 08:51:43 2016 +0000
@@ -21,9 +21,9 @@
 #include <stdint.h>
 
 /**
  * A common container for types and constants used everywhere in BLE API.
  */
-struct BLEProtocol {
+namespace BLEProtocol {
     /**< Address-type for Protocol addresses. */
     struct AddressType { /* Adding a struct to encapsulate the contained enumeration
                             * prevents polluting the BLEProtocol namespace with the
@@ -21,9 +21,9 @@
 
 /**
- * A common container for types and constants used everywhere in BLE API.
+ * A common namespace for types and constants used everywhere in BLE API.
  */